#' Spectral Embedding of Adjacency Matrices
#'
#' @details
#' Given a symmetric adjacency matrix \eqn{A}
#' and a positive integer dimension \eqn{d}
#' compute the adjacency spectral embedding of \eqn{A} into \eqn{R^d}.
#' The adjacency spectral embedding is given by \eqn{U_d S_d^{1/2}}
#' where \eqn{U_d S_d V_d^{\top}} is the rank-\eqn{d} thin SVD of \eqn{A}.
#'
#' @param A a (random) symmetric adjacency matrix
#' @param dim a maximum embedding dimension
#'
#' @return A.coord Estimated latent positions, an n times dim matrix
#' @author Minh Tang
#' @seealso \code{\link{embed_adjacency_matrix}}
#' @export

stfp <- function(A, dim){
    if(nrow(A) >= 400) {
        suppressMessages(require(irlba))
        A.svd <- irlba(A, nu = dim, nv = dim)
    }
    else{
        A.svd <- svd(A)
    }
    A.svd.values <- A.svd$d[1:dim]
    A.svd.vectors <- A.svd$v[,1:dim]
    if(dim == 1)
        A.coords <- sqrt(A.svd.values) * A.svd.vectors
    else
        A.coords <- A.svd.vectors %*% diag(sqrt(A.svd.values))

    return(A.coords)
}

